<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ms">
<context>
    <name>MircastShowWidget</name>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="57"/>
        <source>Exit Miracast</source>
        <translation>Keluar dari Miracast</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="74"/>
        <source>Projecting... 
Please do not exit the Movie app during the process.</source>
        <translation>Mengunjur...
Jangan tutup apl Cereka ketika proses masih berlangsung.</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="102"/>
        <source>Display device</source>
        <translation>Peranti paparan</translation>
    </message>
</context>
<context>
    <name>MircastWidget</name>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="71"/>
        <source>Project to</source>
        <translation>Unjur ke</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="369"/>
        <source>Searching for devices...</source>
        <translation>Menggelintar peranti...</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="378"/>
        <source>No Miracast display devices were found. Please connect the device and your computer to the same WLAN network.</source>
        <translation>Tiada peranti paparan Miracast ditemui. Sila sambungkan peranti dengan komputer anda dalam rangkaian WLAN yang sama.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/backends/mpv/mpv_proxy.cpp" line="582"/>
        <source>Movie</source>
        <translation>Cereka</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="289"/>
        <source>Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats.</source>
        <translation>Cereka ialah sebuah pemain video berciri-lengkap, yang dapat memainkan media setempat dan penstriman dalam pelbagai format video.</translation>
    </message>
    <message>
        <location filename="../src/common/shortcut_manager.cpp" line="186"/>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <location filename="../src/common/shortcut_manager.cpp" line="189"/>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <location filename="../src/common/shortcut_manager.cpp" line="194"/>
        <source>Display shortcuts</source>
        <translation>Papar pintasan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="10"/>
        <source>Auto add similar files to play</source>
        <translation>Auto tambah fail serupa yang hendak dimainkan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="11"/>
        <source>Clear playlist when exit</source>
        <translation>Kosongkan senarai main bila keluar</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="12"/>
        <source>Show thumbnails in progress bar</source>
        <translation>Tunjuk imej kenit dalam palang kemajuan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="13"/>
        <source>Show video preview on mouseover</source>
        <translation>Tunjuk pratonton video jika penuding tetikus di atas</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="14"/>
        <source>Open a new player for each file played</source>
        <translation>Buka satu pemain baharu bagi setiap fail yang dimainkan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="15"/>
        <source>Pause when minimized</source>
        <translation>Jeda bila diminimumkan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="16"/>
        <source>Remember playback position</source>
        <translation>Ingat kedudukan main balik</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="17"/>
        <source>Default play mode</source>
        <translation>Mod main lalai</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="18"/>
        <source>Path</source>
        <translation>Laluan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="19"/>
        <source>Basic</source>
        <translation>Asas</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="20"/>
        <source>Play</source>
        <translation>Main</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="21"/>
        <source>Screenshot</source>
        <translation>Tangkap layar</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="22"/>
        <source>Shortcuts</source>
        <translation>Pintasan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="23"/>
        <source>File</source>
        <translation>Fail</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="24"/>
        <source>Frame/Sound</source>
        <translation>Bingkai/Bunyi</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="25"/>
        <source>Playback</source>
        <translation>Main balik</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="27"/>
        <source>Subtitle</source>
        <translation>Sari kata </translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="29"/>
        <source>Font Style</source>
        <translation>Gaya Fon</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="30"/>
        <source>Restore Defaults</source>
        <translation>Pulih ke Lalai</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="31"/>
        <source>Open file</source>
        <translation>Buka fail</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="32"/>
        <source>Open next</source>
        <translation>Buka berikutnya</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="33"/>
        <source>Open previous</source>
        <translation>Buka terdahulu</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="34"/>
        <source>Mini mode</source>
        <translation>Mod mini</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="35"/>
        <source>Mute</source>
        <translation>Senyap</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="36"/>
        <source>Next frame</source>
        <translation>Bingkai berikutnya</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="37"/>
        <source>Previous frame</source>
        <translation>Bingkai terdahulu</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="38"/>
        <source>Volume down</source>
        <translation>Volum turun</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="39"/>
        <source>Volume up</source>
        <translation>Volum naik</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="40"/>
        <source>Speed up</source>
        <translation>Kelajuan naik</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="41"/>
        <source>Speed down</source>
        <translation>Kelajuan turun</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="42"/>
        <source>Fullscreen</source>
        <translation>Skrin Penuh</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="43"/>
        <source>Pause/Play</source>
        <translation>Jeda/Main</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="44"/>
        <source>Playlist</source>
        <translation>Senarai Main</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="45"/>
        <source>Reset speed</source>
        <translation>Tetap semula kelajuan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="46"/>
        <source>Delete from playlist</source>
        <translation>Padam daripada senarai main</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="47"/>
        <source>Film info</source>
        <translation>Maklumat filem</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="48"/>
        <source>Rewind</source>
        <translation>Mandir</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="49"/>
        <source>Forward</source>
        <translation>Maju</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="50"/>
        <source>Burst shooting</source>
        <translation>Penggambaran meledak</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="51"/>
        <source>Film screenshot</source>
        <translation>Tangkap layar filem</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="52"/>
        <source>0.5s backward</source>
        <translation>0.5s mengundur</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="53"/>
        <source>0.5s forward</source>
        <translation>0.5s dimajukan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="54"/>
        <source>Font</source>
        <translation>Fon</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="55"/>
        <source>Size</source>
        <translation>Saiz</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="56"/>
        <source>Exit fullscreen/mini mode</source>
        <translation>Keluar dari mod skrin penuh/mini</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="60"/>
        <source>Decoding</source>
        <translation>Penyahkodan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="61"/>
        <source>Auto select (Recommended)</source>
        <translation>Auto pilih (Disarankan)</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="62"/>
        <source>Hardware decoding</source>
        <translation>Penyahkodan perkakasan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="63"/>
        <source>Software decoding</source>
        <translation>Penyahkodan perisian</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="64"/>
        <source>Customize</source>
        <translation>Kutamize</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="65"/>
        <source>Decode mode</source>
        <translation>Mod Decode</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="66"/>
        <source>Video out</source>
        <translation>Video Keluar</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="67"/>
        <source>Rendering engine</source>
        <translation>Engine Penjajaran</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="322"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Anda tidak mendapat keizinan untuk mengoperasi folder ini</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="324"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="340"/>
        <source>Invalid folder</source>
        <translation>Folder tidak sah</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="360"/>
        <source>Open folder</source>
        <translation>Buka folder</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2872"/>
        <source>The custom decoding method needs to be restarted before it can take effect,
and whether to restart it?</source>
        <translation>Kaedah pecah kod yang dikutamize perlu dimulakan semula sebelum ia berkesan,

dan sama ada untuk memulakan semula?</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3261"/>
        <source>Network disconnected</source>
        <translation>Rangkaian terputus</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="19"/>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="20"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="26"/>
        <source>Please enter the URL:</source>
        <translation>Sila masukkan URL:</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <location filename="../src/common/actions.cpp" line="53"/>
        <source>Open file</source>
        <translation>Buka fail</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="55"/>
        <source>Open folder</source>
        <translation>Buka folder</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="56"/>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="66"/>
        <source>Play Mode</source>
        <translation>Mod Main</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="68"/>
        <source>Order Play</source>
        <translation>Tertib Main</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="69"/>
        <source>Shuffle Play</source>
        <translation>Kocok Main</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="70"/>
        <source>Single Play</source>
        <translation>Sekali Main</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="71"/>
        <source>Single Loop</source>
        <translation>Ulang Tunggal</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="72"/>
        <source>List Loop</source>
        <translation>Ulang Senarai</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="77"/>
        <source>Frame</source>
        <translation>Bingkai</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="79"/>
        <source>Default</source>
        <translation>Lalai</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="86"/>
        <source>Clockwise</source>
        <translation>Ikut Jam</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="87"/>
        <source>Counterclockwise</source>
        <translation>Lawan Jam</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="89"/>
        <source>Next Frame</source>
        <translation>Bingkai Berikutnya</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="90"/>
        <source>Previous Frame</source>
        <translation>Bingkai Terdahulu</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="99"/>
        <source>Playback Speed</source>
        <translation>Kelajuan Main Balik</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="101"/>
        <source>0.5x</source>
        <translation>0.5x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="102"/>
        <source>1.0x</source>
        <translation>1.0x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="103"/>
        <source>1.2x</source>
        <translation>1.2x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="104"/>
        <source>1.5x</source>
        <translation>1.5x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="105"/>
        <source>2.0x</source>
        <translation>2.0x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="129"/>
        <source>Open URL</source>
        <translation>Buka URL</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="130"/>
        <source>Open CD/DVD</source>
        <translation>Buka CD/DVD</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="132"/>
        <source>Fullscreen</source>
        <translation>Skrin Penuh</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="133"/>
        <source>Mini Mode</source>
        <translation>Mod Mini</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="134"/>
        <source>Always on Top</source>
        <translation>Sentiasa di Atas</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="187"/>
        <source>Sound</source>
        <translation>Bunyi</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="191"/>
        <source>Channel</source>
        <translation>Saluran</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="194"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="195"/>
        <source>Left channel</source>
        <translation>Saluran kiri</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="196"/>
        <source>Right channel</source>
        <translation>Saluran kanan</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="201"/>
        <source>Track</source>
        <translation>Trek</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="214"/>
        <source>Subtitle</source>
        <translation>Sari kata </translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="216"/>
        <source>Load</source>
        <translation>Muat</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="217"/>
        <source>Online Search</source>
        <translation>Gelintar Dalam Talian</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="221"/>
        <source>Select</source>
        <translation>Pilih</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="225"/>
        <source>Hide</source>
        <translation>Sembunyi</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="228"/>
        <source>Encodings</source>
        <translation>Pengekodan</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="295"/>
        <source>Screenshot</source>
        <translation>Tangkap layar</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="298"/>
        <source>Film Screenshot</source>
        <translation>Tangkap Layar Filem</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="299"/>
        <source>Burst Shooting</source>
        <translation>Penggambaran Meledak</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="300"/>
        <source>Open screenshot folder</source>
        <translation>Buka folder tangkap layar</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="308"/>
        <source>Playlist</source>
        <translation>Senarai Main</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="309"/>
        <source>Film Info</source>
        <translation>Maklumat Filem</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="375"/>
        <source>Delete from playlist</source>
        <translation>Padam daripada senarai main</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="376"/>
        <source>Empty playlist</source>
        <translation>Senarai main kosong</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="377"/>
        <source>Display in file manager</source>
        <translation>Papar dalam pengurus fail</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="378"/>
        <source>Film info</source>
        <translation>Maklumat filem</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="44"/>
        <source>Duration: %1</source>
        <translation>Tempoh: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="49"/>
        <source>Resolution: %1</source>
        <translation>: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="54"/>
        <source>Size: %1</source>
        <translation>Saiz: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="77"/>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1013"/>
        <source>Load successfully</source>
        <translation>Berjaya dimuatkan</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1013"/>
        <source>Load failed</source>
        <translation>Gagal dimuatkan</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1852"/>
        <source>Cannot play the disc</source>
        <translation>Tidak dapat memainkan cakera</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1869"/>
        <source>Parse failed</source>
        <translation>Gagal dihuraikan</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1877"/>
        <source>Open folder</source>
        <translation>Buka folder</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2284"/>
        <source>Speed: %1x</source>
        <translation>Kelajuan: %1x</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2323"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2328"/>
        <source>Left channel</source>
        <translation>Saluran kiri</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2333"/>
        <source>Right channel</source>
        <translation>Saluran kanan</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2438"/>
        <source>Track: %1</source>
        <translation>Trek: %1</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2480"/>
        <source>Unable to adjust the subtitle</source>
        <translation>Gagal melaras sari kata</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2485"/>
        <source>Subtitle %1: %2s</source>
        <translation>Sari kata %1: %2s</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2486"/>
        <source>delayed</source>
        <translation>lengah</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2486"/>
        <source>advanced</source>
        <translation>lanjutan</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2644"/>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2653"/>
        <source>Film screenshot</source>
        <translation>Tangkap layar filem</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2654"/>
        <source>Saved to</source>
        <translation>Disimpan ke</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2675"/>
        <source>The screenshot is saved</source>
        <translation>Tangkap layar telah disimpan</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2679"/>
        <source>Failed to save the screenshot</source>
        <translation>Gagal menyimpan tangkap layar</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2763"/>
        <source>Taking the screenshots, please wait...</source>
        <translation>Mengambil tangkap layar, tunggu sebentar...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2848"/>
        <source>Cancel</source>
        <translation type="unfinished">Batal</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2849"/>
        <source>Restart</source>
        <translation>Mulakan Semula</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3054"/>
        <source>Reading DVD files...</source>
        <translation>Membaca fail DVD...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4966"/>
        <source>Invalid file: %1</source>
        <translation>Fail tidak sah: %1</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4997"/>
        <source>Miracast disconnected</source>
        <translation>Miracast terputus</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3275"/>
        <source>No matching online subtitles</source>
        <translation>Tiada sari kata dalam talian yang sepadan</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1913"/>
        <source>All (*)</source>
        <translation>Semua (*)</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3291"/>
        <source>4K video may be stuck</source>
        <translation>Video 4K mungkin tersekat-sekat</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3292"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3324"/>
        <source>Order play</source>
        <translation>Main bertertib</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3327"/>
        <source>Shuffle play</source>
        <translation>Main berkocok</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3330"/>
        <source>Single play</source>
        <translation>Main tunggal</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3333"/>
        <source>Single loop</source>
        <translation>Sekali ulang</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3336"/>
        <source>List loop</source>
        <translation>Ulang senarai</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3480"/>
        <source>Buffering...</source>
        <translation>Menimbal...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3503"/>
        <source>Mute</source>
        <translation>Senyap</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3505"/>
        <source>Volume: %1%</source>
        <translation>Volum: %1%</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3548"/>
        <source>Cannot open file or stream</source>
        <translation>Tidak dapat membuka fail atau strim</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4955"/>
        <source>The action is not supported in this video</source>
        <translation>Tindakan tidak disokong dalam video ini</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4990"/>
        <source>Connection failed</source>
        <translation>Sambungan gagal</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3616"/>
        <source>Invalid file</source>
        <translation>Fail tidak sah</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2531"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation>Sari kata (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3623"/>
        <source>Please insert a CD/DVD</source>
        <translation>Sila masukkan satu CD/DVD</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3628"/>
        <source>No video file found</source>
        <translation>Tiada fail video ditemui</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4279"/>
        <source>Please load the video first</source>
        <translation>Sila muatkan video terlebih dahulu</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4402"/>
        <source>Please exit smart dock</source>
        <translation>Sila keluar dari labuh pintar</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4715"/>
        <source>The CD/DVD has been ejected</source>
        <translation>CD/DVD telah dilentingkan</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <source>%1G</source>
        <translation type="vanished">%1G</translation>
    </message>
    <message>
        <source>%1M</source>
        <translation type="vanished">%1M</translation>
    </message>
    <message>
        <source>%1K</source>
        <translation type="vanished">%1K</translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="vanished">%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="243"/>
        <source>Film info</source>
        <translation>Maklumat filem</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="295"/>
        <source>Type</source>
        <translation>Jenis</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="296"/>
        <source>Size</source>
        <translation>Saiz</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="297"/>
        <source>Duration</source>
        <translation>Tempoh</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="302"/>
        <source>Path</source>
        <translation>Laluan</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="307"/>
        <source>Codec info</source>
        <translation>Maklumat kodeks</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="328"/>
        <source>Video CodecID</source>
        <translation>IDKodeks Video</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="329"/>
        <source>Video CodeRate</source>
        <translation>KadarKod Video</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="275"/>
        <source>%1 kbps</source>
        <translation>%1 kbps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="276"/>
        <source>%1 bps</source>
        <translation>%1 bps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="330"/>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="278"/>
        <source>%1 fps</source>
        <translation>%1 fps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="331"/>
        <source>Proportion</source>
        <translation>Perkadaran</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="279"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="332"/>
        <source>Resolution</source>
        <translation>Resolusi</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="337"/>
        <source>Audio info</source>
        <translation>Maklumat audio</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="358"/>
        <source>Audio CodecID</source>
        <translation>IDKodeks Audio</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="359"/>
        <source>Audio CodeRate</source>
        <translation>KadarKod Audio</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="360"/>
        <source>Audio digit</source>
        <translation>Digit audio</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="291"/>
        <source>%1 bits</source>
        <translation>%1 bit</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="361"/>
        <source>Channels</source>
        <translation>Saluran</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="292"/>
        <source>%1 channels</source>
        <translation>%1 saluran</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="362"/>
        <source>Sampling</source>
        <translation>Persampelan</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="293"/>
        <source>%1hz</source>
        <translation>%1hz</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <location filename="../src/backends/mpv/mpv_proxy.cpp" line="1990"/>
        <source>Internal</source>
        <translation>Dalaman</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_MainWindow</name>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1037"/>
        <source>Load successfully</source>
        <translation>Berjaya dimuatkan</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1037"/>
        <source>Load failed</source>
        <translation>Gagal dimuatkan</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1915"/>
        <source>Cannot play the disc</source>
        <translation>Tidak dapat memainkan cakera</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1932"/>
        <source>Parse failed</source>
        <translation>Gagal dihuraikan</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1940"/>
        <source>Open folder</source>
        <translation>Buka folder</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1968"/>
        <source>All (*)</source>
        <translation>Semua (*)</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2300"/>
        <source>Speed: %1x</source>
        <translation>Kelajuan: %1x</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2339"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2344"/>
        <source>Left channel</source>
        <translation>Saluran kiri</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2349"/>
        <source>Right channel</source>
        <translation>Saluran kanan</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2454"/>
        <source>Track: %1</source>
        <translation>Trek: %1</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2496"/>
        <source>Unable to adjust the subtitle</source>
        <translation>Gagal melaras sari kata</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2501"/>
        <source>Subtitle %1: %2s</source>
        <translation>Sari kata %1: %2s</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2502"/>
        <source>delayed</source>
        <translation>lengah</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2502"/>
        <source>advanced</source>
        <translation>lanjutan</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2547"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation>Sari kata (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2670"/>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2679"/>
        <source>Film screenshot</source>
        <translation>Tangkap layar filem</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2680"/>
        <source>Saved to</source>
        <translation>Disimpan ke</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2701"/>
        <source>The screenshot is saved</source>
        <translation>Tangkap layar telah disimpan</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2705"/>
        <source>Failed to save the screenshot</source>
        <translation>Gagal menyimpan tangkap layar</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2789"/>
        <source>Taking the screenshots, please wait...</source>
        <translation>Mengambil tangkap layar, tunggu sebentar...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2873"/>
        <source>Cancel</source>
        <translation type="unfinished">Batal</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2874"/>
        <source>Restart</source>
        <translation>Mulakan Semula</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3064"/>
        <source>Reading DVD files...</source>
        <translation>Membaca fail DVD...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3268"/>
        <source>No matching online subtitles</source>
        <translation>Tiada sari kata dalam talian yang sepadan</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3284"/>
        <source>4K video may be stuck</source>
        <translation>Video 4K mungkin tersekat-sekat</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3285"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3326"/>
        <source>Order play</source>
        <translation>Main bertertib</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3329"/>
        <source>Shuffle play</source>
        <translation>Main berkocok</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3332"/>
        <source>Single play</source>
        <translation>Sekali main</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3335"/>
        <source>Single loop</source>
        <translation>Sekali ulang</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3338"/>
        <source>List loop</source>
        <translation>Ulang senarai</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3476"/>
        <source>Buffering...</source>
        <translation>Menimbal...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3499"/>
        <source>Mute</source>
        <translation>Senyap</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3501"/>
        <source>Volume: %1%</source>
        <translation>Volum: %1%</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3570"/>
        <source>Cannot open file or stream</source>
        <translation>Tidak dapat membuka fail atau strim</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3587"/>
        <source>Invalid file</source>
        <translation>Fail tidak sah</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3594"/>
        <source>Please insert a CD/DVD</source>
        <translation>Sila masukkan satu CD/DVD</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3600"/>
        <source>No video file found</source>
        <translation>Tiada fail video ditemui</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4283"/>
        <source>Please load the video first</source>
        <translation>Sila muatkan video terlebih dahulu</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4403"/>
        <source>Please exit smart dock</source>
        <translation>Sila keluar dari labuh pintar</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4655"/>
        <source>The CD/DVD has been ejected</source>
        <translation>CD/DVD telah dilentingkan</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4901"/>
        <source>The action is not supported in this video</source>
        <translation>Tindakan tidak disokong dalam video ini</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4912"/>
        <source>Invalid file: %1</source>
        <translation>Fail tidak sah: %1</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4936"/>
        <source>Connection failed</source>
        <translation>Sambungan gagal</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4943"/>
        <source>Miracast disconnected</source>
        <translation>Miracast terputus</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlayItemWidget</name>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="163"/>
        <source>The file does not exist</source>
        <translation>Fail tidak wujud</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlaylistWidget</name>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="679"/>
        <source>Playlist</source>
        <translation>Senarai Main</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="705"/>
        <source>Empty</source>
        <translation>Kosong</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="910"/>
        <source>%1 videos</source>
        <translation>%1 video</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_ToolboxProxy</name>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1189"/>
        <source>Play/Pause</source>
        <translation>Main/Jeda</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1189"/>
        <source>Previous</source>
        <translation>Terdahulu</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1189"/>
        <source>Next</source>
        <translation>Berikutnya</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1190"/>
        <source>Fullscreen</source>
        <translation>Skrin Penuh</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1190"/>
        <source>Playlist</source>
        <translation>Senarai Main</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1190"/>
        <source>Miracast</source>
        <translation>Miracast</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2132"/>
        <source>Exit fullscreen</source>
        <translation>Keluar dari skrin penuh</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2217"/>
        <source>Pause</source>
        <translation>Jeda</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2277"/>
        <source>Play</source>
        <translation>Main</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="163"/>
        <source>The file does not exist</source>
        <translation>Fail tidak wujud</translation>
    </message>
</context>
<context>
    <name>dmr::PlaylistWidget</name>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="679"/>
        <source>Playlist</source>
        <translation>Senarai Main</translation>
    </message>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="705"/>
        <source>Empty</source>
        <translation>Kosong</translation>
    </message>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="910"/>
        <source>%1 videos</source>
        <translation>%1 video</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="119"/>
        <source>Order play</source>
        <translation>Main bertertib</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="120"/>
        <source>Shuffle play</source>
        <translation>Main berkocok</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="121"/>
        <source>Single play</source>
        <translation>Sekali main</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="122"/>
        <source>Single loop</source>
        <translation>Sekali ulang</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="123"/>
        <source>List loop</source>
        <translation>Ulang senarai</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="129"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="130"/>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="131"/>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="294"/>
        <source>%1/Movie%2(%3).jpg</source>
        <translation>%1/Cereka%2(%3).jpg</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1313"/>
        <source>Play/Pause</source>
        <translation>Main/Jeda</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1313"/>
        <source>Previous</source>
        <translation>Terdahulu</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1313"/>
        <source>Next</source>
        <translation>Berikutnya</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1314"/>
        <source>Fullscreen</source>
        <translation>Skrin Penuh</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1314"/>
        <source>Playlist</source>
        <translation>Senarai Main</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1314"/>
        <source>Miracast</source>
        <translation>Miracast</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2306"/>
        <source>Exit fullscreen</source>
        <translation>Keluar dari skrin penuh</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2402"/>
        <source>Pause</source>
        <translation>Jeda</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2467"/>
        <source>Play</source>
        <translation>Main</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2842"/>
        <source>Volume</source>
        <translation type="unfinished">Volum</translation>
    </message>
</context>
<context>
    <name>dmr::VolumeButton</name>
    <message>
        <location filename="../src/widgets/toolbutton.cpp" line="19"/>
        <source>Volume</source>
        <translation>Volum</translation>
    </message>
</context>
</TS>
